--[[----------------------------------------------------------------------------

ViewbookExportDialogSections.lua
Export dialog customization for Lightroom Viewbook uploader

--------------------------------------------------------------------------------

VIEWBOOK B.V.
 Copyright 2012-2008 Viewbook B.V.
 All Rights Reserved.



------------------------------------------------------------------------------]]

	-- Lightroom SDK
local LrBinding = import 'LrBinding'
local LrView = import "LrView"
local LrHttp = import 'LrHttp'
local LrXml = import 'LrXml'

local bind = LrView.bind
local share = LrView.share

--Logging
--local logger = import 'LrLogger'( 'ViewbookAPILog' )
--local debug, info, warn, err = logger:quick( 'debug', 'info', 'warn', 'err' )
--Viewbook
--logger:enable( "logfile" ) 


require 'ViewbookAPI'

--============================================================================--

ViewbookExportDialogSections = {}

-------------------------------------------------------------------------------

function ViewbookExportDialogSections.startDialog( propertyTable )

	propertyTable.LR_canExport = false
	propertyTable.addToPhotoset = false
	propertyTable.photoset = nil

	-- Can't export until we've validated the login.
	propertyTable.LR_cantExportBecause = LOC "$$$/Viewbook/ExportDialog/NoLogin=You haven't logged in to Viewbook yet."

	-- Make sure we're logged in.
	require 'ViewbookUser'
	ViewbookUser.verifyLogin( propertyTable )
		
	-- observe the addToPhotoset
 	propertyTable:addObserver( 'addToPhotoset', ViewbookAPI.getPhotoSets)

	-- observe if a value is added to photoset, then enable export
	propertyTable:addObserver( 'photoset', 
	function()
	--info('photoset',propertyTable.photoset)
		if propertyTable.photoset == nil then
			--info('photosets FALSE')
			propertyTable.LR_canExport = false
		else
		--info('photosets TRUE')
			propertyTable.LR_canExport = true
			propertyTable.LR_cantExportBecause = false
		end
	end )
end

-------------------------------------------------------------------------------

function ViewbookExportDialogSections.sectionsForTopOfDialog( f, propertyTable )
propertyTable.loading = false;

	return {
	
		{
			title = LOC "$$$/Viewbook/ExportDialog/Account=Viewbook Account",
			
			synopsis = bind 'accountStatus',

			f:row {
				spacing = f:control_spacing(),

				f:static_text {
					title = bind 'accountStatus',
					alignment = 'right',
					fill_horizontal = 1,
				},

				f:push_button {
					width = 90,
					title = bind 'loginButtonTitle',
					enabled = bind 'loginButtonEnabled',
					action = function()
						require 'ViewbookUser'
						ViewbookUser.login( propertyTable )
					end,
				},
			},
		},
	
	
	-- Add to Album
		{
			title = LOC "$$$/Viewbook/ExportDialog/Add to Album (required)=Add to Album (required)",

			f:row {
						
				f:static_text {
					title = LOC "$$$/Viewbook/ExportDialog/NewAlbum=Add to New Album",
				},

				f:edit_field {
					value = bind 'new_photoset',
					immediate = true, -- update value w/every keystroke 
				},
				
				f:push_button {
					title = LOC "$$$/Viewbook/ExportDialog/NewPhotoset=Create",
					action = function() ViewbookExportDialogSections.createNewPhotoset( propertyTable ) end,						
				},
				
				f:static_text {
					title = LOC "$$$/Viewbook/ExportDialog/ChooseAlbum=Loading...",
					visible = bind 'loading';
				},
				
			},
			
			f:row {
				margin_bottom = f:control_spacing() / 2,

				f:checkbox {
					title = LOC "$$$/Viewbook/ExportDialog/AddToPhotoSet=Add to Existing Album:",
					value = bind 'addToPhotoset',
					unchecked_value = false,
				}, 

				f:popup_menu {
					value = bind 'photoset', 
					enabled = bind 'addToPhotoset',
					items = bind 'photosets',
				},

			},
			-- Viewbook doesn't need those Privacy and Safety interfaces 
			--[[
				{
						title = LOC "$$$/Viewbook/ExportDialog/PrivacyAndSafety=Privacy and Safety",
						synopsis = function( props )

							local summary = {}

							local function add( x )
								if x then
									summary[ #summary + 1 ] = x
								end
							end

							if props.privacy == 'private' then
								add( LOC "$$$/Viewbook/ExportDialog/Private=Private" )
								if props.privacy_family then
									add( LOC "$$$/Viewbook/ExportDialog/Family=Family" )
								end
								if props.privacy_friends then
									add( LOC "$$$/Viewbook/ExportDialog/Friends=Friends" )
								end
							else
								add( LOC "$$$/Viewbook/ExportDialog/Public=Public" )
							end

							local safetyStr = kSafetyTitles[ props.safety ]
							if safetyStr then
								add( safetyStr )
							end

							-- Etc. (rest left as an exercise for the reader)

							return table.concat( summary, " / " )

						end,

						place = 'horizontal',

						f:column {
							spacing = f:control_spacing() / 2,
							fill_horizontal = 1,

							f:row {
								f:static_text {
									title = LOC "$$$/Viewbook/ExportDialog/Privacy=Privacy:",
									alignment = 'right',
									width = share 'labelWidth',
								},

								f:radio_button {
									title = LOC "$$$/Viewbook/ExportDialog/Private=Private",
									checked_value = 'private',
									value = bind 'privacy',
								},
							},

							f:row {
								f:spacer {
									width = share 'labelWidth',
								},

								f:column {
									spacing = f:control_spacing() / 2,
									margin_left = 15,
									margin_bottom = f:control_spacing() / 2,

									f:checkbox {
										title = LOC "$$$/Viewbook/ExportDialog/Family=Family",
										value = bind 'privacy_family',
										enabled = LrBinding.keyEquals( 'privacy', 'private' ),
									},

									f:checkbox {
										title = LOC "$$$/Viewbook/ExportDialog/Friends=Friends",
										value = bind 'privacy_friends',
										enabled = LrBinding.keyEquals( 'privacy', 'private' ),
									},
								},
							},

							f:row {
								f:spacer {
									width = share 'labelWidth',
								},

								f:radio_button {
									title = LOC "$$$/Viewbook/ExportDialog/Public=Public",
									checked_value = 'public',
									value = bind 'privacy',
								},
							},
						},

						f:column {
							spacing = f:control_spacing() / 2,

							fill_horizontal = 1,

							f:row {
								f:static_text {
									title = LOC "$$$/Viewbook/ExportDialog/Safety=Safety:",
									alignment = 'right',
									width = share 'flickr_col2_label_width',
								},

								f:popup_menu {
									value = bind 'safety',
									width = share 'flickr_col2_popup_width',
									items = {
										{ title = kSafetyTitles.safe, value = 'safe' },
										{ title = kSafetyTitles.moderate, value = 'moderate' },
										{ title = kSafetyTitles.restricted, value = 'restricted' },
									},
								},
							},

							f:row {
								margin_bottom = f:control_spacing() / 2,

								f:spacer {
									width = share 'flickr_col2_label_width',
								},

								f:checkbox {
									title = LOC "$$$/Viewbook/ExportDialog/HideFromPublicSite=Hide from public site areas",
									value = bind 'hideFromPublic',
								},
							},

							f:row {
								f:static_text {
									title = LOC "$$$/Viewbook/ExportDialog/Type=Type:",
									alignment = 'right',
									width = share 'flickr_col2_label_width',
								},

								f:popup_menu {
									width = share 'flickr_col2_popup_width',
									value = bind 'type',
									items = {
										{ title = LOC "$$$/Viewbook/ExportDialog/Type/Photo=Photo", value = 'photo' },
										{ title = LOC "$$$/Viewbook/ExportDialog/Type/Screenshot=Screenshot", value = 'screenshot' },
										{ title = LOC "$$$/Viewbook/ExportDialog/Type/Other=Other", value = 'other' },
									},
								},
							},
						},
					},

					--]]
--[[
			f:row {
				f:spacer {
					width = share 'labelWidth',
				},

				f:static_text {
					title = LOC "$$$/Viewbook/ExportDialog/TagMergeNote=These tags will be combined with the exported keywords from each photo.",
					fill_horizontal = 1,
					height_in_lines = 2,
					width_in_chars = 32,
				},
			},
--]]
		
		},

	
	
	
	}

end

-------------------------------------------------------------------------------

local kSafetyTitles = {
	safe = LOC "$$$/Viewbook/ExportDialog/Safety/Safe=Safe",
	moderate = LOC "$$$/Viewbook/ExportDialog/Safety/Moderate=Moderate",
	restricted = LOC "$$$/Viewbook/ExportDialog/Safety/Restricted=Restricted",
}

function ViewbookExportDialogSections.sectionsForBottomOfDialog( f, propertyTable )
	propertyTable.loading = false;

	return {
	}
	
end



-------------------------------------------------------------------------------
-- Create new PhotoSet
function ViewbookExportDialogSections.createNewPhotoset(propertyTable)
	params = {}
	params.title = propertyTable.new_photoset
	ViewbookAPI.createPhotoSet(params, propertyTable)
end






